geodanet
========

Datasets from GeoDaNet for network analysis
-------------------------------------------

* crimes.dbf: attribute data for crime point set. (k=2)
* crimes.prj: ESRI projection file.
* crimes.sbn: spatial index.
* crimes.sbx: spatial index.
* crimes.shp: Point shapefile for crime data. (n=287)
* crimes.shp.xml: metadata.
* crimes.shx: spatial index.
* schools.dbf: attribute data for schools point set. (k=1)
* schools.prj: ESRI projection file.
* schools.sbn: spatial index.
* schools.sbx: spatial index.
* schools.shp: Point shapefile for schools data. (n=8)
* schools.shp.xml: metadata.
* schools.shx: spatial index.
* streets.dbf: attribute data for street polyline set. (k=2)
* streets.prj: ESRI projection file.
* streets.sbn: spatial index.
* streets.sbx: spatial index.
* streets.shp: Line shapefile data for street data. (n=293)
* streets.shx: spatial index.
